@@ -4,6 +4,7 @@ from .manage_file import create_all_parents, searching_all_files, unzip, pbar
 from . import load_google_drive
 from . import google
 from . import stutils
+from . import meteo_v0 as stmeteo_v0
 from . import meteo as stmeteo
 from . import easy_import
 # from .pickle_wrapper import load_pickle, dump_pickle
@@ -14,7 +15,7 @@ __all__ = [
     "Yaml", 
     "Montre", 
     "create_all_parents", "searching_all_files", "unzip", "pbar",
-    "load_google_drive", "google", "stmeteo",
+    "load_google_drive", "google", "stmeteo_v0", "stmeteo",
     # "load_pickle", "dump_pickle",
     "stutils", "regress2", 'concordance_correlation_coefficient',
     "easy_import"
